@@ -5,6 +5,14 @@ import warnings
 
 
 # copied from stemia.cryosparc.csplot
+
+def update_dict(d1, d2):
+    for k1, v in d1.items():
+        for k2 in v:
+            if not d1[k1][k2]:
+                d1[k1][k2].update(d2[k1][k2])
+
+
 def find_cs_files(job_dir, sets=None):
     """
     Recursively explore a job directory to find all the relevant cs files.
@@ -61,14 +69,19 @@ def find_cs_files(job_dir, sets=None):
                 for k in dct:
                     dct[k] = set(sorted(dct[k])[-1:])
 
-    def update(d1, d2):
-        for k1, v in d1.items():
-            for k2 in v:
-                if not d1[k1][k2]:
-                    d1[k1][k2].update(d2[k1][k2])
+    # remove non-existing files
+    for dct in files.values():
+        for kind, file_set in dct.items():
+            for f in list(file_set):
+                if not f.exists():
+                    warnings.warn(
+                        'the following file was supposed to contain relevant information, '
+                        f'but does not exist:\n{f}'
+                    )
+                    file_set.remove(f)
 
     for parent in job['parents']:
-        update(files, find_cs_files(job_dir.parent / parent))
+        update_dict(files, find_cs_files(job_dir.parent / parent))
         if all(file_set for dct in files.values() for file_set in dct.values()):
             # found everything we need
             break
